@@ -28,7 +28,7 @@ pub struct InvalidateCtx<'info> {
     issuer_token_account: UncheckedAccount<'info>,
 }
 
-pub fn handler(ctx: Context<InvalidateCtx>) -> ProgramResult {
+pub fn handler<'key, 'accounts, 'remaining, 'info>(ctx: Context<'key, 'accounts, 'remaining, 'info, InvalidateCtx<'info>>) -> ProgramResult {
     let token_manager_key = ctx.accounts.token_manager.key();
     let time_invalidator_seeds = &[TIME_INVALIDATOR_SEED.as_bytes(), token_manager_key.as_ref(), &[ctx.accounts.time_invalidator.bump]];
     let time_invalidator_signer = &[&time_invalidator_seeds[..]];
@@ -40,10 +40,12 @@ pub fn handler(ctx: Context<InvalidateCtx>) -> ProgramResult {
         mint: ctx.accounts.mint.to_account_info(),
         recipient_token_account: ctx.accounts.recipient_token_account.to_account_info(),
         issuer_token_account: ctx.accounts.issuer_token_account.to_account_info(),
-        invalidator: ctx.accounts.invalidator.to_account_info(),
+        invalidator: ctx.accounts.time_invalidator.to_account_info(),
         token_program: ctx.accounts.token_program.to_account_info(),
     };
-    let cpi_ctx = CpiContext::new(ctx.accounts.cardinal_token_manager.to_account_info(), cpi_accounts).with_signer(time_invalidator_signer);
+    let cpi_ctx = CpiContext::new(ctx.accounts.cardinal_token_manager.to_account_info(), cpi_accounts)
+        .with_remaining_accounts(ctx.remaining_accounts.to_vec())
+        .with_signer(time_invalidator_signer);
     cardinal_token_manager::cpi::invalidate(cpi_ctx)?;
   
     return Ok(())
