@@ -14,7 +14,7 @@ pub mod cardinal_time_invalidator {
         init::handler(ctx, bump, expiration)
     }
 
-    pub fn invalidate(ctx: Context<InvalidateCtx>) -> ProgramResult {
+    pub fn invalidate<'key, 'accounts, 'remaining, 'info>(ctx: Context<'key, 'accounts, 'remaining, 'info, InvalidateCtx<'info>>) -> ProgramResult {
         invalidate::handler(ctx)
     }
 }
\ No newline at end of file
